@@ -18,7 +18,8 @@ setClass("GAlignments",
     ),
     prototype(
         seqnames=Rle(factor()),
-        strand=Rle(strand())
+        strand=Rle(strand()),
+        elementMetadata=new("DFrame")
     )
 )
 
@@ -110,7 +111,8 @@ setMethod("updateObject", "GAlignments",
                         "Updating it ...")
             object@elementType <- new(class(object))@elementType
         }
-        object
+
+        callNextMethod()
     }
 )
 
